@@ -283,14 +283,6 @@ class UrlNotDvcRepoError(DvcException):
         )
 
 
-class GetDVCFileError(DvcException):
-    def __init__(self):
-        super(GetDVCFileError, self).__init__(
-            "the given path is a DVC-file, you must specify a data file "
-            "or a directory"
-        )
-
-
 class GitHookAlreadyExistsError(DvcException):
     def __init__(self, hook_name):
         super(GitHookAlreadyExistsError, self).__init__(
