@@ -1,7 +1,6 @@
-from dvc.utils.compat import pathlib
-from dvc.repo.scm_context import scm_context
-
 from . import locked as locked_repo
+from dvc.repo.scm_context import scm_context
+from dvc.utils import resolve_output
 
 
 @locked_repo
@@ -9,20 +8,18 @@ from . import locked as locked_repo
 def imp_url(self, url, out=None, fname=None, erepo=None, locked=True):
     from dvc.stage import Stage
 
-    out = out or pathlib.PurePath(url).name
+    out = resolve_output(url, out)
 
-    with self.state:
-        stage = Stage.create(
-            self, cmd=None, deps=[url], outs=[out], fname=fname, erepo=erepo
-        )
+    stage = Stage.create(
+        self, cmd=None, deps=[url], outs=[out], fname=fname, erepo=erepo
+    )
 
     if stage is None:
         return None
 
     self.check_modified_graph([stage])
 
-    with self.state:
-        stage.run()
+    stage.run()
 
     stage.locked = locked
 
